@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2017 Canonical, Ltd.
+ * Copyright (C) 2017 Canonical Ltd.
  * Copyright (C) 2014 John Layt <jlayt@kde.org>
  * Copyright (C) 2002, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2013, 2014 Red Hat, Inc.
  * Copyright (C) 2008 Novell, Inc.
@@ -794,11 +794,11 @@ bool IppClient::isStringPrintable(const QString &string, const bool checkNull,
 void IppClient::setInternalStatus(const QString &status)
 {
     if (!m_internalStatus.isNull()) {
-        m_internalStatus = QString::null;
+        m_internalStatus = QString();
     }
 
     if (status.isNull()) {
-        m_internalStatus = QString::null;
+        m_internalStatus = QString();
     } else {
         m_internalStatus = status;
 
